#
# spec file for package sgmltool
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sgmltool
Version:        1.0.9
Release:        1078.1
Summary:        SGML-Tools - a Text-Formatting Package
License:        SUSE-Public-Domain
Group:          Productivity/Publishing/SGML
Source:         ftp://ftp.nllgg.nl/pub2/SGMLtools/v1.0/sgml-tools-%{version}.tar.bz2
Source1:        lnd-1.0.tar.bz2
Patch0:         sgml-tools-1.0.9.dif
Patch1:         sgml-tools-temp-vuln-1.0.9.diff
Patch2:         sgmltool-man-entities.diff
Patch3:         sgmltool-1.0.9-expandsyntax.diff
Patch4:         sgml-tools-1.0.9-destdir.diff
Patch5:         sgml-tools-retval.diff
Patch6:         cflags-sgml-tools-1.0.9.diff
Patch7:         sgml-tools-1.0.9-sgmlpre.diff
Patch8:         sgml-tools-1.0.9-strip.diff
Patch9:         sgml-tools-1.0.9-latex.diff
BuildRequires:  flex
BuildRequires:  groff
BuildRequires:  opensp
BuildRequires:  texlive-kpathsea
Requires:       opensp
Requires:       perl = %{perl_version}
Requires:       perl(Text::EntityMap)
Conflicts:      linuxdoc
Provides:       sgml-tools
%{expand: %%global _texmfmaindir %(kpsewhich -expand-var='$TEXMFMAIN')}

%description
SGML-Tools is a text-formatting package based on SGML (Standard
Generalized Markup Language), which allows you to produce LaTeX, HTML,
GNU info, LyX, RTF, and plain ASCII documents (via groff) from a single
source.

This system is tailored for writing technical software documentation,
an example of which is the Linux HOWTO documents. It should be useful
for all kinds of printed and online documentation.

This package is the successor to the Linuxdoc package.

SGML-Tools cannot process arbitrary SGML documents. In such a case, try
jade_dsl and write your own DSSSL scripts (take the docbk30 package as
an example).

%package latex
Summary:        SGML-Tools - LaTeX generator
Group:          Productivity/Publishing/SGML
Requires:       sgmltool
Requires:       texlive-epsf
Requires:       texlive-latex
Requires:       texlive-url
Requires(post): coreutils
Requires(posttrans): texlive-filesystem
Requires(postun): coreutils
Requires(postun): texlive-kpathsea
Supplements:    (sgmltool and texlive-filesystem)
Provides:       sgmltool:%{_bindir}/sgml2latex

%description latex
This package contains the LaTeX generator (sgml2latex) from sgmltool.

%prep
%setup -q -n sgml-tools-%{version} -a1
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8
%patch -P 9

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
    --prefix="%{buildroot}/%{_prefix}" \
    --with-installed-nsgmls
make %{?_smp_mflags}
make %{?_smp_mflags} install DESTDIR=%{buildroot} prefix="%{_prefix}"
(cd doc; PATH="$PATH:%buildroot/%{_bindir}" sh Makedoc.sh)
cp -p doc/README doc/README.doc
# the Makefiles are a bit nasty
make %{?_smp_mflags} clean
%configure \
    --with-installed-nsgmls
make %{?_smp_mflags}

%install
> doc/Makedoc.sh
make install DESTDIR="%{buildroot}";
rm -fr %{buildroot}%{_prefix}/doc/sgml-tools
perlpath=`ls -1d %{_prefix}/lib/perl5/5.*/Text`
mkdir -p %{buildroot}$perlpath
mv %{buildroot}%{_prefix}/lib/perl5/Text/EntityMap.pm %{buildroot}$perlpath/

%post latex
mkdir -p %{_localstatedir}/run/texlive
> %{_localstatedir}/run/texlive/run-mktexlsr

%postun latex
if test $1 = 0; then
    %{_bindir}/mktexlsr 2> /dev/null || :
    exit 0
fi
mkdir -p %{_localstatedir}/run/texlive
> %{_localstatedir}/run/texlive/run-mktexlsr

%posttrans latex
VERBOSE=false %{_texmfmaindir}/texconfig/update || :

%files
%license COPYING
%doc lnd-1.0
%doc BUGS CHANGES CONTRIBUTORS README TODO
%doc doc/README.doc doc/example.sgml doc/html
%doc doc/guide.ps.gz doc/guide.sgml doc/guide.txt
%{_bindir}/sgmlsasp
%{_bindir}/rtf2rtf
%{_bindir}/sgmltools.v1
%{_bindir}/sgml2html
%{_bindir}/sgml2info
%{_bindir}/sgml2lyx
%{_bindir}/sgml2rtf
%{_bindir}/sgml2txt
%{_bindir}/sgmlcheck
%{_bindir}/sgmlpre
%dir %{_prefix}/lib/entity-map
%{_prefix}/lib/entity-map/0.1.0
%{_prefix}/lib/perl5/5.*/Text/EntityMap.pm
%dir %{_prefix}/lib/sgml
%{_prefix}/lib/sgml-tools
%{_prefix}/lib/sgml/iso-entities-8879.1986
%{_mandir}/man1/sgml2html.1%{?ext_man}
%{_mandir}/man1/sgml2info.1%{?ext_man}
%{_mandir}/man1/sgml2lyx.1%{?ext_man}
%{_mandir}/man1/sgml2rtf.1%{?ext_man}
%{_mandir}/man1/sgml2txt.1%{?ext_man}
%{_mandir}/man1/sgmlsasp.1%{?ext_man}
%{_mandir}/man1/sgmlcheck.1%{?ext_man}
%{_mandir}/man1/sgmltools.1%{?ext_man}

%files latex
%{_bindir}/sgml2latex
%{_texmfmaindir}/tex/latex/sgml-tools
%{_mandir}/man1/sgml2latex.1%{?ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Sep 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add suplements for the sgml2latex to make sure it gets
  autoinstalled if one has both latex and sgmltool
* Fri Sep 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Move sgml2latex to separate subpackage, avoid pulling in half
  of TeXLive when e.g. only sgml2html is required.
- Really remove sgmltool-flex.patch, was only applied for obsolete
  distribution versions.
- Stop distributing RTF and LyX versions of the guide; plaintext,
  HTML and Postscript should be sufficient.
- spec file cleanup:
  * drop defattr, use license, use buildroot instead of shell variable
  * remove long obsolete distro support
* Wed Feb 18 2015 schwab@linux-m68k.org
- sgmltool-flex.patch: removed, flex has been fixed
* Mon Sep  9 2013 werner@suse.de
- Use kpsepath to determine texmf main location
* Wed Dec 12 2012 nfbrown@suse.com
- Add buildrequires for groff so that sgml2txt
  works, and rationalize setting of CFLAGS.
  In particular having a "\" line continuation
  before a %%configure macro probably doesn't
  behave as expected.
* Mon Nov 19 2012 idonmez@suse.com
- Add sgmltool-flex.patch: yyleng must be size_t with new flex
* Thu Aug  2 2012 jengelh@inai.de
- Parallel build with %%_smp_mflags
- Remove redundant tags/sections from specfile,
  use %%configure
* Mon Jul 30 2012 werner@suse.de
- Move styles where they belong to
- Require packages for sgml2latex
- Use texlive infrastructure
* Mon Jul 30 2012 werner@suse.de
- Quote brackets of the babel language mapping otherwise the
  sgml2latex tool ignores it
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Thu Aug  7 2008 ke@suse.de
- Improve Perl requires.  Recommended by Staphan Kulow, reported by
  Jan Willamowius [bnc#412525].
* Wed Apr 23 2008 ro@suse.de
- do not redefine "name" macro
* Thu Mar 29 2007 ke@suse.de
- Add BuildRequires: flex.
* Sat May 27 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 10 2005 ke@suse.de
- Use -fno-strict-aliasing.
- Add missing return value; thanks for debugging to Richard Guenther.
* Fri Jun 17 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Wed Apr 28 2004 ro@suse.de
- added missing return value (unreached code)
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Wed Apr 23 2003 coolo@suse.de
- use more of that DESTDIR
* Tue Apr 22 2003 coolo@suse.de
- don't mess with broken Makefiles -> empty it before execution
* Tue Apr 22 2003 coolo@suse.de
- generating docs through brute force
* Wed Apr 16 2003 coolo@suse.de
- use BuildRoot
* Mon Apr  7 2003 mmj@suse.de
- The expand syntax changed with new coreutils.
* Mon Nov 11 2002 ro@suse.de
- adapted requires
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <sp> to <opensp>
- changed neededforbuild <sp-devel> to <>
* Thu Jun 20 2002 ke@suse.de
- sgmltool-man-entities.diff: Try to map entities also for manpage
  output; reported by Michal Svec [# 16536].
- enable %%clean section.
* Fri Mar  8 2002 kukuk@suse.de
- Add /usr/lib/entity-map to filelist
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Thu Apr 26 2001 ke@suse.de
- Apply tools-temp-vuln-1.0.9.diff to fix a tmp file vulnerability
  (patch provided by Sebastian Krahmer) [#6826].
* Thu Jan 27 2000 ke@suse.de
- add more documentation lnd-1.0.tar.bz2 (thanks to mike for hint).
- use macros: %%{name}, %%{version}, %%{_mandir}.
- ./configure -> %%build section.
- add group tag.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jul  9 1999 bs@suse.de
- fixed path for perl module
* Tue Jun 29 1999 ke@suse.de
- babel now will know the language as an option (werner).
* Mon Apr 26 1999 ro@suse.de
- compiler fix: stdout is non constant
* Thu Nov 26 1998 ke@suse.de
- update: version 1.0.9 (bugfix release).
- mv the perl module to the 5.00502 dir hierarchy (hack).
* Wed Nov 18 1998 ro@suse.de
- adapt path to perl 5.00502
* Mon Nov  9 1998 ro@suse.de
- added sp_libs to neededforbuild
* Fri Oct 16 1998 ke@suse.de
- update: version 1.0.8 (bugfix release).
* Sun Jun 28 1998 ke@suse.de
- update: version 1.0.7 (bugfix release).
- remove jade_dsl from neededforbuild.
* Mon Mar 23 1998 bs@suse.de
- added sp to neededforbuild
* Fri Mar  6 1998 ke@suse.de
- update: version 1.0.5.
* Sat Feb 28 1998 bs@suse.de
- deleted texhash stuff (done by tetex package now)
* Sun Feb 15 1998 ke@suse.de
- update: version 1.0.4.
- simplify file list.
* Tue Jan 13 1998 ke@suse.de
- update: version 1.0.3
* Wed Nov 19 1997 ke@suse.de
- provide %%post and %%postun script to maintain /var/texfonts/ls-R.
* Mon Nov 17 1997 ke@suse.de
- initial package: version 0.99.20.
